summaryrefslogtreecommitdiff
path: root/lib/nickname.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/nickname.php')
-rw-r--r--lib/nickname.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/nickname.php b/lib/nickname.php
index 48269f3b9..a0c9378cd 100644
--- a/lib/nickname.php
+++ b/lib/nickname.php
@@ -23,7 +23,7 @@ class Nickname
* Regex fragment for pulling an arbitrarily-formated nickname.
*
* Not guaranteed to be valid after normalization; run the string through
* Nickname::normalize() to get the canonical form, or Nickname::validate()
* if you just need to check if it's properly formatted.
*
* This and CANONICAL_FMT replace the old NICKNAME_FMT, but be aware
@@ -61,7 +61,7 @@ class Nickname
* @param string $str
* @return boolean
*/
- public static function validate($str)
+ public static function isValid($str)
{
try {
self::normalize($str);
@@ -23,7 +23,7 @@ class Nickname
*
* Not guaranteed to be valid after normalization; run the string through
- * Nickname::normalize() to get the canonical form, or Nickname::validate()
+ * Nickname::normalize() to get the canonical form, or Nickname::isValid()
* if you just need to check if it's properly formatted.
*